@@ -15,9 +15,9 @@ def _copy_site_files_here() -> None:
     """Copies all files from site packaging location into current root location."""
     Template.files_from(
         from_path=os.path.join(
-            site.getsitepackages()[0],
+            site.getsitepackages()[0],  # pylint:disable=no-member
             os.path.dirname(__file__),
-            "template",  # pylint:disable=no-member
+            "template",
         )
     )
 
@@ -49,6 +49,7 @@ class _Meta(AbstractStyle):
     def build_analyser(self) -> None:
         """Builds analyser file."""
         replace_content(Template.ANALYSER.value, from_replace="<package>", to_replace=self._name)
+        os.system(command=f"chmod a+x {Template.ANALYSER}")
 
     def build_readme(self) -> None:
         """Builds readme file."""
